@@ -20,19 +20,19 @@ summary(plan,brief=TRUE)
 ### various split-plot setups
 planfull <-FrF2(32,5,WPs=4,nfac.WP=2,factor.names=Letters[21:25])
 summary(planfull, brief=TRUE)
-design.info(planfull)
+design.info(planfull)[-which(names(design.info(planfull))=="FrF2.version")]
 try(planfull <-FrF2(32,5,WPs=4,nfac.WP=3,factor.names=Letters[21:25]))
 
 plan0 <-FrF2(32,7,gen=c(6,15),WPs=4,WPfacs=c("B","C","F"),factor.names=Letters[19:25])
 summary(plan0,brief=TRUE)
-design.info(plan0)
+design.info(plan0)[-which(names(design.info(plan0))=="FrF2.version")]
 
 plan <-FrF2(32,7,WPs=4,nfac.WP=3,factor.names=Letters[19:25])
 summary(plan, brief=TRUE)
 generators(plan)
-design.info(plan)
+design.info(plan)[-which(names(design.info(plan))=="FrF2.version")]
 
 plan2 <- FrF2(32,7,gen=c(6,15),WPs=4,nfac.WP=3,WPfacs=c(2,3,6),factor.names=Letters[19:25])
 summary(plan2, brief=TRUE)
 generators(plan2)
-design.info(plan2)
+design.info(plan2)[-which(names(design.info(plan2))=="FrF2.version")]
